### R code from vignette source 'patchDVI.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: patchDVI.Rnw:84-85 (eval = FALSE)
###################################################
## install.packages("patchDVI")


###################################################
### code chunk number 2: patchDVI.Rnw:89-90 (eval = FALSE)
###################################################
## install.packages("patchDVI", repos="http://R-forge.r-project.org")


###################################################
### code chunk number 3: patchDVI.Rnw:101-103 (eval = FALSE)
###################################################
## library(patchDVI)
## SweavePDF("doc.Rnw")


